@@ -3,9 +3,6 @@ package api
 import gitlab "gitlab.com/gitlab-org/api/client-go"
 
 var GetProject = func(client *gitlab.Client, projectID any) (*gitlab.Project, error) {
-	if client == nil {
-		client = apiClient.Lab()
-	}
 	opts := &gitlab.GetProjectOptions{
 		License:              gitlab.Ptr(true),
 		WithCustomAttributes: gitlab.Ptr(true),
@@ -18,9 +15,6 @@ var GetProject = func(client *gitlab.Client, projectID any) (*gitlab.Project, er
 }
 
 var DeleteProject = func(client *gitlab.Client, projectID any) (*gitlab.Response, error) {
-	if client == nil {
-		client = apiClient.Lab()
-	}
 	project, err := client.Projects.DeleteProject(projectID, nil)
 	if err != nil {
 		return nil, err
@@ -29,9 +23,6 @@ var DeleteProject = func(client *gitlab.Client, projectID any) (*gitlab.Response
 }
 
 var CreateProject = func(client *gitlab.Client, opts *gitlab.CreateProjectOptions) (*gitlab.Project, error) {
-	if client == nil {
-		client = apiClient.Lab()
-	}
 	project, _, err := client.Projects.CreateProject(opts)
 	if err != nil {
 		return nil, err
@@ -40,9 +31,6 @@ var CreateProject = func(client *gitlab.Client, opts *gitlab.CreateProjectOption
 }
 
 var ForkProject = func(client *gitlab.Client, projectID any, opts *gitlab.ForkProjectOptions) (*gitlab.Project, error) {
-	if client == nil {
-		client = apiClient.Lab()
-	}
 	project, _, err := client.Projects.ForkProject(projectID, opts)
 	if err != nil {
 		return nil, err
@@ -51,9 +39,6 @@ var ForkProject = func(client *gitlab.Client, projectID any, opts *gitlab.ForkPr
 }
 
 var GetGroup = func(client *gitlab.Client, groupID any) (*gitlab.Group, error) {
-	if client == nil {
-		client = apiClient.Lab()
-	}
 	group, _, err := client.Groups.GetGroup(groupID, &gitlab.GetGroupOptions{})
 	if err != nil {
 		return nil, err
@@ -62,9 +47,6 @@ var GetGroup = func(client *gitlab.Client, groupID any) (*gitlab.Group, error) {
 }
 
 var ListGroupProjects = func(client *gitlab.Client, groupID any, opts *gitlab.ListGroupProjectsOptions) ([]*gitlab.Project, *gitlab.Response, error) {
-	if client == nil {
-		client = apiClient.Lab()
-	}
 	project, resp, err := client.Groups.ListGroupProjects(groupID, opts)
 	if err != nil {
 		return nil, nil, err
@@ -73,9 +55,6 @@ var ListGroupProjects = func(client *gitlab.Client, groupID any, opts *gitlab.Li
 }
 
 var ListProjectsGroups = func(client *gitlab.Client, projectID any, opts *gitlab.ListProjectGroupOptions) ([]*gitlab.ProjectGroup, error) {
-	if client == nil {
-		client = apiClient.Lab()
-	}
 	groups, _, err := client.Projects.ListProjectsGroups(projectID, opts)
 	if err != nil {
 		return nil, err
@@ -84,9 +63,6 @@ var ListProjectsGroups = func(client *gitlab.Client, projectID any, opts *gitlab
 }
 
 var ListProjectMembers = func(client *gitlab.Client, projectID any, opts *gitlab.ListProjectMembersOptions) ([]*gitlab.ProjectMember, error) {
-	if client == nil {
-		client = apiClient.Lab()
-	}
 	members, _, err := client.ProjectMembers.ListAllProjectMembers(projectID, opts)
 	if err != nil {
 		return nil, err
