@@ -65,8 +65,8 @@ func NewCmdApi(f *cmdutils.Factory, runF func(*ApiOptions) error) *cobra.Command
 		The endpoint argument should either be a path of a GitLab API v4 endpoint, or
 		"graphql" to access the GitLab GraphQL API.
 
-		- [GitLab REST API documentation](https://docs.gitlab.com/ee/api/index.html)
-		- [GitLab GraphQL documentation](https://docs.gitlab.com/ee/api/graphql/)
+		- [GitLab REST API documentation](https://docs.gitlab.com/api/)
+		- [GitLab GraphQL documentation](https://docs.gitlab.com/api/graphql/)
 
 		If the current directory is a Git directory, uses the GitLab authenticated host in the current
 		directory. Otherwise, %[1]sgitlab.com%[1]s will be used.
@@ -119,6 +119,8 @@ func NewCmdApi(f *cmdutils.Factory, runF func(*ApiOptions) error) *cobra.Command
 
 			- glab api issues --paginate
 
+			$ glab api graphql -f query="query { currentUser { username } }"
+
 			$ glab api graphql -f query='
 			  query {
 			    project(fullPath: "gitlab-org/gitlab-docs") {
@@ -212,7 +214,7 @@ func apiRun(opts *ApiOptions) error {
 	}
 	method := opts.RequestMethod
 	requestHeaders := opts.RequestHeaders
-	var requestBody interface{} = params
+	var requestBody any = params
 
 	if !opts.RequestMethodPassed && (len(params) > 0 || opts.RequestInputFile != "") {
 		method = http.MethodPost
@@ -259,9 +261,14 @@ func apiRun(opts *ApiOptions) error {
 		host = opts.Hostname
 	}
 
+	client, err := api.NewClientWithCfg(host, opts.Config, isGraphQL)
+	if err != nil {
+		return err
+	}
+
 	hasNextPage := true
 	for hasNextPage {
-		resp, err := httpRequest(api.GetClient(), opts.Config, host, method, requestPath, requestBody, requestHeaders)
+		resp, err := httpRequest(client, method, requestPath, requestBody, requestHeaders)
 		if err != nil {
 			return err
 		}
@@ -432,8 +439,8 @@ func printHeaders(w io.Writer, headers http.Header, colorize bool) {
 	}
 }
 
-func parseFields(opts *ApiOptions) (map[string]interface{}, error) {
-	params := make(map[string]interface{})
+func parseFields(opts *ApiOptions) (map[string]any, error) {
+	params := make(map[string]any)
 	for _, f := range opts.RawFields {
 		key, value, err := parseField(f)
 		if err != nil {
@@ -463,7 +470,7 @@ func parseField(f string) (string, string, error) {
 	return f[0:idx], f[idx+1:], nil
 }
 
-func magicFieldValue(v string, opts *ApiOptions) (interface{}, error) {
+func magicFieldValue(v string, opts *ApiOptions) (any, error) {
 	if strings.HasPrefix(v, "@") {
 		return readUserFile(v[1:], opts.IO.In)
 	}
@@ -531,7 +538,7 @@ func parseErrorResponse(r io.Reader, statusCode int) (io.Reader, string, error)
 	err = json.Unmarshal(b, &parsedBody)
 	if err != nil {
 		// in cases where it's an object within an object we can try to parse it as is
-		var t interface{}
+		var t any
 		err = json.Unmarshal(b, &t)
 		if err != nil {
 			return r, "", err
