@@ -8,7 +8,7 @@ import (
 	"github.com/MakeNowJust/heredoc/v2"
 	"github.com/google/shlex"
 	"github.com/stretchr/testify/require"
-	"github.com/xanzy/go-gitlab"
+	gitlab "gitlab.com/gitlab-org/api/client-go"
 	"gitlab.com/gitlab-org/cli/api"
 	"gitlab.com/gitlab-org/cli/commands/cmdutils"
 	"gitlab.com/gitlab-org/cli/commands/issuable"
@@ -202,6 +202,6 @@ func TestIssuableUnsubscribe(t *testing.T) {
 		iid := 404
 		_, err := runCommand(fakeHTTP, fmt.Sprint(iid), issuable.TypeIssue)
 
-		require.Contains(t, err.Error(), "404 not found")
+		require.Contains(t, err.Error(), "404 Not Found")
 	})
 }
