@@ -72,11 +72,11 @@ func NewCmdCreate(f *cmdutils.Factory) *cobra.Command {
 		Long:    ``,
 		Aliases: []string{"new"},
 		Example: heredoc.Doc(`
-			- glab issue create
-			- glab issue new
-			- glab issue create -m release-2.0.0 -t "we need this feature" --label important
-			- glab issue new -t "Fix CVE-YYYY-XXXX" -l security --linked-mr 123
-			- glab issue create -m release-1.0.1 -t "security fix" --label security --web --recover
+			$ glab issue create
+			$ glab issue new
+			$ glab issue create -m release-2.0.0 -t "we need this feature" --label important
+			$ glab issue new -t "Fix CVE-YYYY-XXXX" -l security --linked-mr 123
+			$ glab issue create -m release-1.0.1 -t "security fix" --label security --web --recover
 		`),
 		Args: cobra.ExactArgs(0),
 		RunE: func(cmd *cobra.Command, args []string) error {
@@ -458,7 +458,7 @@ func generateIssueWebURL(opts *CreateOpts) (string, error) {
 
 	if len(opts.Labels) > 0 {
 		// this uses the slash commands to add labels to the description
-		// See https://docs.gitlab.com/ee/user/project/quick_actions.html
+		// See https://docs.gitlab.com/user/project/quick_actions/
 		// See also https://gitlab.com/gitlab-org/gitlab-foss/-/issues/19731#note_32550046
 		description += "\n/label"
 		for _, label := range opts.Labels {
