@@ -10,7 +10,7 @@ import (
 func NewCmdJob(f *cmdutils.Factory) *cobra.Command {
 	jobCmd := &cobra.Command{
 		Use:   "job <command> [flags]",
-		Short: `Work with GitLab CI/CD jobs`,
+		Short: `Work with GitLab CI/CD jobs.`,
 		Long:  ``,
 	}
 
