@@ -7,20 +7,20 @@ import (
 	"gitlab.com/gitlab-org/cli/api"
 
 	"github.com/spf13/cobra"
-	"github.com/xanzy/go-gitlab"
+	gitlab "gitlab.com/gitlab-org/api/client-go"
 	"gitlab.com/gitlab-org/cli/commands/cmdutils"
 )
 
 func NewCmdCreate(f *cmdutils.Factory) *cobra.Command {
 	labelCreateCmd := &cobra.Command{
 		Use:     "create [flags]",
-		Short:   `Create labels for repository/project`,
+		Short:   `Create labels for a repository or project.`,
 		Long:    ``,
 		Aliases: []string{"new"},
 		Example: heredoc.Doc(`
-			glab label create
-			glab label new
-			glab label create -R owner/repo
+			- glab label create
+			- glab label new
+			- glab label create -R owner/repo
 		`),
 		Args: cobra.ExactArgs(0),
 		RunE: func(cmd *cobra.Command, args []string) error {
@@ -57,10 +57,10 @@ func NewCmdCreate(f *cmdutils.Factory) *cobra.Command {
 			return nil
 		},
 	}
-	labelCreateCmd.Flags().StringP("name", "n", "", "Name of label")
+	labelCreateCmd.Flags().StringP("name", "n", "", "Name of the label.")
 	_ = labelCreateCmd.MarkFlagRequired("name")
-	labelCreateCmd.Flags().StringP("color", "c", "#428BCA", "Color of label in plain or HEX code.")
-	labelCreateCmd.Flags().StringP("description", "d", "", "Label description")
+	labelCreateCmd.Flags().StringP("color", "c", "#428BCA", "Color of the label, in plain or HEX code.")
+	labelCreateCmd.Flags().StringP("description", "d", "", "Label description.")
 
 	return labelCreateCmd
 }
