@@ -18,17 +18,17 @@ func NewCmdClose(f *cmdutils.Factory) *cobra.Command {
 		Short: `Close a merge request.`,
 		Long:  ``,
 		Example: heredoc.Doc(`
-			- glab mr close 1
+			$ glab mr close 1
 
-			Close multiple merge requests at once
-			- glab mr close 1 2 3 4
+			# Close multiple merge requests at once
+			$ glab mr close 1 2 3 4
 
-			Use the checked-out branch
-			- glab mr close
+			# Use the checked-out branch
+			$ glab mr close
 
-			- glab mr close branch
-			- glab mr close username:branch
-			- glab mr close branch -R another/repo
+			$ glab mr close branch
+			$ glab mr close username:branch
+			$ glab mr close branch -R another/repo
 		`),
 		RunE: func(cmd *cobra.Command, args []string) error {
 			var err error
