@@ -94,11 +94,11 @@ func NewCmdCreate(f *cmdutils.Factory) *cobra.Command {
 		Long:    ``,
 		Aliases: []string{"new"},
 		Example: heredoc.Doc(`
-			- glab mr new
-			- glab mr create -a username -t "fix annoying bug"
-			- glab mr create -f --draft --label RFC
-			- glab mr create --fill --web
-			- glab mr create --fill --fill-commit-body --yes
+			$ glab mr new
+			$ glab mr create -a username -t "fix annoying bug"
+			$ glab mr create -f --draft --label RFC
+			$ glab mr create --fill --web
+			$ glab mr create --fill --fill-commit-body --yes
 		`),
 		Args: cobra.ExactArgs(0),
 		PreRun: func(cmd *cobra.Command, args []string) {
@@ -757,7 +757,7 @@ func generateMRCompareURL(opts *CreateOpts) (string, error) {
 
 	if len(opts.Labels) > 0 {
 		// this uses the slash commands to add labels to the description
-		// See https://docs.gitlab.com/ee/user/project/quick_actions.html
+		// See https://docs.gitlab.com/user/project/quick_actions/
 		// See also https://gitlab.com/gitlab-org/gitlab-foss/-/issues/19731#note_32550046
 		description += fmt.Sprintf("\n/label ~%s", strings.Join(opts.Labels, ", ~"))
 	}
