@@ -23,14 +23,14 @@ func NewCmdFor(f *cmdutils.Factory) *cobra.Command {
 		Long:    ``,
 		Aliases: []string{"new-for", "create-for", "for-issue"},
 		Example: heredoc.Doc(`
-			Create merge request for issue 34
-			- glab mr for 34
+			# Create merge request for issue 34
+			$ glab mr for 34
 
-			Create merge request for issue 34 and mark as work in progress
-			- glab mr for 34 --wip
+			# Create merge request for issue 34 and mark as work in progress
+			$ glab mr for 34 --wip
 
-			- glab mr new-for 34
-			- glab mr create-for 34
+			$ glab mr new-for 34
+			$ glab mr create-for 34
 		`),
 		Args: cobra.ExactArgs(1),
 		RunE: func(cmd *cobra.Command, args []string) error {
