@@ -11,7 +11,7 @@ import (
 	"gitlab.com/gitlab-org/cli/commands/mr/mrutils"
 	"gitlab.com/gitlab-org/cli/pkg/utils"
 
-	"github.com/xanzy/go-gitlab"
+	gitlab "gitlab.com/gitlab-org/api/client-go"
 )
 
 func NewCmdIssues(f *cmdutils.Factory) *cobra.Command {
@@ -22,9 +22,12 @@ func NewCmdIssues(f *cmdutils.Factory) *cobra.Command {
 		Aliases: []string{"issue"},
 		Args:    cobra.MaximumNArgs(1),
 		Example: heredoc.Doc(`
-			glab mr issues 46
-			glab mr issues branch
-			glab mr issues  # use checked out branch
+			# List issues for merge request 46
+			$ glab mr issues 46
+			$ glab mr issues branch
+
+			# Use the checked-out branch
+			$ glab mr issues
 		`),
 		RunE: func(cmd *cobra.Command, args []string) error {
 			var err error
