@@ -55,9 +55,9 @@ func NewCmdFork(f *cmdutils.Factory, runE func(*cmdutils.Factory) error) *cobra.
 		Use:   "fork <repo>",
 		Short: "Fork a GitLab repository.",
 		Example: heredoc.Doc(`
-			- glab repo fork
-			- glab repo fork namespace/repo
-			- glab repo fork namespace/repo --clone
+			$ glab repo fork
+			$ glab repo fork namespace/repo
+			$ glab repo fork namespace/repo --clone
 		`),
 		Args: cobra.MaximumNArgs(1),
 		RunE: func(cmd *cobra.Command, args []string) (err error) {
@@ -173,7 +173,7 @@ loop:
 		skipFirstCheck = false
 		// check import status of Fork
 		// Import status should be one of {none, failed, scheduled, started, finished}
-		// https://docs.gitlab.com/ee/api/project_import_export.html#import-status
+		// https://docs.gitlab.com/api/project_import_export/#import-status
 		switch forkedProject.ImportStatus {
 		case "none": // no import initiated
 			break loop
