@@ -5,7 +5,7 @@ import (
 	"fmt"
 
 	"github.com/AlecAivazis/survey/v2"
-
+	"github.com/MakeNowJust/heredoc/v2"
 	"github.com/spf13/cobra"
 	"gitlab.com/gitlab-org/cli/commands/cmdutils"
 	"gitlab.com/gitlab-org/cli/pkg/git"
@@ -28,10 +28,12 @@ func baseCommand() (git.Stack, error) {
 
 func NewCmdStackFirst(f *cmdutils.Factory, gr git.GitRunner) *cobra.Command {
 	return &cobra.Command{
-		Use:     "first",
-		Short:   "Moves to the first diff in the stack. (EXPERIMENTAL.)",
-		Long:    "Moves to the first diff in the stack, and checks out that branch.\n" + text.ExperimentalString,
-		Example: "glab stack first",
+		Use:   "first",
+		Short: "Moves to the first diff in the stack. (EXPERIMENTAL.)",
+		Long:  "Moves to the first diff in the stack, and checks out that branch.\n" + text.ExperimentalString,
+		Example: heredoc.Doc(`
+			$ glab stack first
+		`),
 		RunE: func(cmd *cobra.Command, args []string) error {
 			stack, err := baseCommand()
 			if err != nil {
@@ -57,10 +59,12 @@ func NewCmdStackFirst(f *cmdutils.Factory, gr git.GitRunner) *cobra.Command {
 
 func NewCmdStackNext(f *cmdutils.Factory, gr git.GitRunner) *cobra.Command {
 	return &cobra.Command{
-		Use:     "next",
-		Short:   "Moves to the next diff in the stack. (EXPERIMENTAL.)",
-		Long:    "Moves to the next diff in the stack, and checks out that branch.\n" + text.ExperimentalString,
-		Example: "glab stack next",
+		Use:   "next",
+		Short: "Moves to the next diff in the stack. (EXPERIMENTAL.)",
+		Long:  "Moves to the next diff in the stack, and checks out that branch.\n" + text.ExperimentalString,
+		Example: heredoc.Doc(`
+			$ glab stack next
+		`),
 		RunE: func(cmd *cobra.Command, args []string) error {
 			stack, err := baseCommand()
 			if err != nil {
@@ -91,10 +95,12 @@ func NewCmdStackNext(f *cmdutils.Factory, gr git.GitRunner) *cobra.Command {
 
 func NewCmdStackPrev(f *cmdutils.Factory, gr git.GitRunner) *cobra.Command {
 	return &cobra.Command{
-		Use:     "prev",
-		Short:   "Moves to the previous diff in the stack. (EXPERIMENTAL.)",
-		Long:    "Moves to the previous diff in the stack, and checks out that branch.\n" + text.ExperimentalString,
-		Example: "glab stack prev",
+		Use:   "prev",
+		Short: "Moves to the previous diff in the stack. (EXPERIMENTAL.)",
+		Long:  "Moves to the previous diff in the stack, and checks out that branch.\n" + text.ExperimentalString,
+		Example: heredoc.Doc(`
+			$ glab stack prev
+		`),
 		RunE: func(cmd *cobra.Command, args []string) error {
 			stack, err := baseCommand()
 			if err != nil {
@@ -125,10 +131,12 @@ func NewCmdStackPrev(f *cmdutils.Factory, gr git.GitRunner) *cobra.Command {
 
 func NewCmdStackLast(f *cmdutils.Factory, gr git.GitRunner) *cobra.Command {
 	return &cobra.Command{
-		Use:     "last",
-		Short:   "Moves to the last diff in the stack. (EXPERIMENTAL.)",
-		Long:    "Moves to the last diff in the stack, and checks out that branch.\n" + text.ExperimentalString,
-		Example: "glab stack last",
+		Use:   "last",
+		Short: "Moves to the last diff in the stack. (EXPERIMENTAL.)",
+		Long:  "Moves to the last diff in the stack, and checks out that branch.\n" + text.ExperimentalString,
+		Example: heredoc.Doc(`
+			$ glab stack last
+		`),
 		RunE: func(cmd *cobra.Command, args []string) error {
 			stack, err := baseCommand()
 			if err != nil {
@@ -155,10 +163,12 @@ func NewCmdStackLast(f *cmdutils.Factory, gr git.GitRunner) *cobra.Command {
 
 func NewCmdStackMove(f *cmdutils.Factory, gr git.GitRunner) *cobra.Command {
 	return &cobra.Command{
-		Use:     "move",
-		Short:   "Moves to any selected entry in the stack. (EXPERIMENTAL.)",
-		Long:    "Shows a menu with a fuzzy finder to select a stack.\n" + text.ExperimentalString,
-		Example: "glab stack move",
+		Use:   "move",
+		Short: "Moves to any selected entry in the stack. (EXPERIMENTAL.)",
+		Long:  "Shows a menu with a fuzzy finder to select a stack.\n" + text.ExperimentalString,
+		Example: heredoc.Doc(`
+			$ glab stack move
+		`),
 		RunE: func(cmd *cobra.Command, args []string) error {
 			stack, err := baseCommand()
 			if err != nil {
